@@ -1,10 +1,10 @@
 package cache
 
 import (
+	netv1 "k8s.io/api/networking/v1"
 	"sync"
 
 	"github.com/derailed/popeye/internal"
-	netv1b1 "k8s.io/api/networking/v1beta1"
 )
 
 // IngressKey tracks Ingress resource references
@@ -12,16 +12,16 @@ const IngressKey = "ing"
 
 // Ingress represents Ingress cache.
 type Ingress struct {
-	ings map[string]*netv1b1.Ingress
+	ings map[string]*netv1.Ingress
 }
 
 // NewIngress returns a new Ingress cache.
-func NewIngress(ings map[string]*netv1b1.Ingress) *Ingress {
+func NewIngress(ings map[string]*netv1.Ingress) *Ingress {
 	return &Ingress{ings: ings}
 }
 
 // ListIngresses returns all available Ingresss on the cluster.
-func (d *Ingress) ListIngresses() map[string]*netv1b1.Ingress {
+func (d *Ingress) ListIngresses() map[string]*netv1.Ingress {
 	return d.ings
 }
 
