@@ -6,24 +6,24 @@ import (
 
 	"github.com/derailed/popeye/internal/client"
 	"github.com/derailed/popeye/internal/dao"
-	polv1 "k8s.io/api/policy/v1"
+	policyv1 "k8s.io/api/policy/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
 // ListPodDisruptionBudgets list all included PodDisruptionBudgets.
-func ListPodDisruptionBudgets(ctx context.Context) (map[string]*polv1.PodDisruptionBudget, error) {
+func ListPodDisruptionBudgets(ctx context.Context) (map[string]*policyv1.PodDisruptionBudget, error) {
 	return listAllPodDisruptionBudgets(ctx)
 }
 
 // ListAllPodDisruptionBudgets fetch all PodDisruptionBudgets on the cluster.
-func listAllPodDisruptionBudgets(ctx context.Context) (map[string]*polv1.PodDisruptionBudget, error) {
+func listAllPodDisruptionBudgets(ctx context.Context) (map[string]*policyv1.PodDisruptionBudget, error) {
 	ll, err := fetchPodDisruptionBudgets(ctx)
 	if err != nil {
 		return nil, err
 	}
-	pdbs := make(map[string]*polv1.PodDisruptionBudget, len(ll.Items))
+	pdbs := make(map[string]*policyv1.PodDisruptionBudget, len(ll.Items))
 	for i := range ll.Items {
 		pdbs[metaFQN(ll.Items[i].ObjectMeta)] = &ll.Items[i]
 	}
@@ -32,7 +32,7 @@ func listAllPodDisruptionBudgets(ctx context.Context) (map[string]*polv1.PodDisr
 }
 
 // fetchPodDisruptionBudgets retrieves all PodDisruptionBudgets on the cluster.
-func fetchPodDisruptionBudgets(ctx context.Context) (*polv1.PodDisruptionBudgetList, error) {
+func fetchPodDisruptionBudgets(ctx context.Context) (*policyv1.PodDisruptionBudgetList, error) {
 	f, cfg := mustExtractFactory(ctx), mustExtractConfig(ctx)
 	if cfg.Flags.StandAlone {
 		dial, err := f.Client().Dial()
@@ -43,14 +43,14 @@ func fetchPodDisruptionBudgets(ctx context.Context) (*polv1.PodDisruptionBudgetL
 	}
 
 	var res dao.Resource
-	res.Init(f, client.NewGVR("policy/v1beta1/poddisruptionbudgets"))
+	res.Init(f, client.NewGVR("policy/v1/poddisruptionbudgets"))
 	oo, err := res.List(ctx)
 	if err != nil {
 		return nil, err
 	}
-	var ll polv1.PodDisruptionBudgetList
+	var ll policyv1.PodDisruptionBudgetList
 	for _, o := range oo {
-		var pdb polv1.PodDisruptionBudget
+		var pdb policyv1.PodDisruptionBudget
 		err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &pdb)
 		if err != nil {
 			return nil, errors.New("expecting pdb resource")
